##  Presentation Details
To navigate to the presentation details page, click the three-dot icon on the presentation, then click Presentation details. Here, you can do the following:
  * Change the presentation name, description, and owner
  * Delete the presentation
  * Change permissions for the presentation
  * Share the presentation with other users and view users with whom it was shared


![Presentation Details Page](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274be8367a441014bc7bb76c2c853a75_LowRes.png)
Presentation Details Page
